Index: trunk/ippScripts/scripts/dist_make_fileset.pl
===================================================================
--- trunk/ippScripts/scripts/dist_make_fileset.pl	(revision 24104)
+++ trunk/ippScripts/scripts/dist_make_fileset.pl	(revision 24125)
@@ -91,5 +91,12 @@
     &my_die("dbinfo file for dist run $dbinfo_file not found", $dist_id, $prod_id, $PS_EXIT_UNKNOWN_ERROR);
 }
-print "dbinfo file $dbinfo_file exists\n";
+print "dbinfo file $dbinfo_file exists\n" if $verbose;
+
+# make sure that the dirinfo file for this run exists
+my $dirinfo_file = "dirinfo.$stage.$stage_id.mdc";
+if (! -e "$dist_dir/$dirinfo_file" ) {
+    &my_die("dirinfo file for dist run $dirinfo_file not found", $dist_id, $prod_id, $PS_EXIT_UNKNOWN_ERROR);
+}
+print "dirinfo file $dirinfo_file exists\n" if $verbose;
 
 # open the dsreg file list
@@ -97,6 +104,7 @@
 
 # add the dbinfo file to the list
 # XXX: change type from text to dbinfo once we descide on types
 print $listFile "$dbinfo_file|||text|dbinfo|\n";
+print $listFile "$dirinfo_file|||text|dirinfo|\n";
 
 my $components;
@@ -97,6 +104,7 @@
 
 # add the dbinfo file to the list
-# XXX: change type from text to dbinfo once we descide on types
+# XXX: change type from text to dbinfo and dirinfo once we define the types
 print $listFile "$dbinfo_file|||text|dbinfo|\n";
